@@ -1,4 +1,3 @@
-import pytest
 import json
 import os
 import sys
@@ -18,11 +17,12 @@ def test_change_all_values():
         assert dictionary["reading_status"]["Reading Status"] == "Maybe Will Read Later..."
 
     # -- testing class ChangeAllValues
-    with pytest.raises(SystemExit) as e:
+    try:
         ChangeAllValues(
             full_path=os.path.join(
                 sys.path[0],
                 "tests/using_classes/ChangeAllValues/books_with_changed_values.json"
             )
         )
-    assert e.value.code == 0
+    except Exception:
+        raise
